@@ -1,7 +1,7 @@
 import os
 import time
 from pathlib import Path
-from typing import Optional
+from typing import Optional, List
 
 import smart_open
 import typer
@@ -76,25 +76,30 @@ def load(
     file_format: str = typer.Option("jsonl", "--ff"),
     dry_run: bool = typer.Option(False, "--dry-run"),
     skip_reindex: bool = typer.Option(False, "--skip-reindex"),
-    mv_split: str = typer.Option("|"),
+    is_binary: bool = typer.Option(False, "--is_binary"),
+    flags: Optional[List[str]] = typer.Option(None, "--flag"),
+    is_transaction: bool = typer.Option(False, "--tx"),
 ):
     """ Load data into local KB """
     t0 = time.time()
-    environ.mv_split = mv_split
 
     kb = KB(root=root)
     typer.echo(f"Loading using {file_format} from {in_file}")
 
+    mode = "rb" if is_binary else "r"
     if in_file == "-":
-        file_obj = typer.open_file(in_file, mode="r")
+        file_obj = typer.open_file(in_file, mode=mode)
     else:
-        file_obj = smart_open.open(in_file, mode="r")
+        file_obj = smart_open.open(in_file, mode=mode)
 
-    reader = cli.get_reader(file_format, file_obj=file_obj, kb=kb)
+    reader = cli.get_reader(
+        file_format=file_format, file_obj=file_obj, kb=kb, flags=flags
+    )
 
     count = 0
+    transact = kb.transact if is_transaction else services.noop_context
     with typer.progressbar(reader) as progress:
-        with kb.transact():
+        with transact():
             for obj in progress:
                 count += 1
 
@@ -116,9 +121,11 @@ def reindex(root: Optional[Path] = typer.Option(None)):
     """ Load data into local KB """
     t0 = time.time()
     kb = KB(root=root)
+    typer.echo(f"Reindexing {kb.config.root}...")
+
     kb.reindex()
     t1 = time.time()
-    typer.echo(f"Reindexed in {t1 - t0:.2f}s")
+    typer.echo(f"Reindexed {kb.config.root} in {t1 - t0:.2f}s")
 
 
 @cli.command(name="rpc")
