@@ -1,3 +1,4 @@
+from contextlib import contextmanager
 import collections
 import os
 
@@ -6,6 +7,11 @@ import typer
 from entitykb import Config, KB, logger
 
 
+@contextmanager
+def noop_context():
+    yield
+
+
 def init_kb(root, exist_ok=False, config=None) -> bool:
     success = False
 
@@ -15,8 +21,7 @@ def init_kb(root, exist_ok=False, config=None) -> bool:
         os.makedirs(str(root), exist_ok=exist_ok)
         Config.create(root=root, config=config)
 
-        kb = KB(root=root)
-        kb.reindex()
+        KB(root=root)
         success = True
 
     except FileExistsError as e:
