@@ -1,5 +1,5 @@
 from .users import User, StoredUser, UserToken
-from .doc import Token, DocToken, Doc, Span, ParseRequest
+from .doc import Token, DocToken, Doc, Span, SpanMatch, ParseRequest
 from .enums import Direction, Comparison, TripleSep, UserStatus
 from .fields import StrTupleField
 from .funcs import (
@@ -9,7 +9,7 @@ from .funcs import (
     under_limit,
     label_filter,
 )
-from .node import Node, Edge, NodeKey, IEdge
+from .node import Node, Edge, NodeKey, IEdge, Neighbor
 from .entity import Entity
 from .traverse import (
     F,
@@ -25,21 +25,26 @@ from .traverse import (
     WalkStep,
 )
 from .registry import Registry
-from .search import SearchRequest, Hop, Trail, SearchResponse, EdgeRequest
+from .search import (
+    CountRequest,
+    Hop,
+    NeighborRequest,
+    NeighborResponse,
+    SearchRequest,
+    SearchResponse,
+    Trail,
+)
 from .serialization import Envelope
 
 __all__ = (
-    "AccessToken",
-    "AccessTokenData",
     "Comparison",
     "Criteria",
+    "CountRequest",
     "Direction",
     "Doc",
-    "Span",
     "DocToken",
     "Edge",
     "EdgeCriteria",
-    "EdgeRequest",
     "Entity",
     "Envelope",
     "F",
@@ -47,12 +52,17 @@ __all__ = (
     "FilterStep",
     "Hop",
     "IEdge",
+    "Neighbor",
+    "NeighborRequest",
+    "NeighborResponse",
     "Node",
     "NodeKey",
     "ParseRequest",
     "Registry",
     "SearchRequest",
     "SearchResponse",
+    "Span",
+    "SpanMatch",
     "Step",
     "StoredUser",
     "StrTupleField",
