@@ -4,11 +4,18 @@ from entitykb.contrib.date import DateResolver, Date
 resolver = DateResolver()
 
 
-def parse_date(s):
+def parse_ent(s) -> Date:
     entities = resolver.resolve(s)
     if entities:
+        # noinspection PyTypeChecker
         d: Date = entities[0]
         assert d.text == s
+        return d
+
+
+def parse_date(s) -> date:
+    d = parse_ent(s)
+    if d:
         return d.as_date
 
 
@@ -42,8 +49,8 @@ def test_is_prefix():
 
 
 def test_is_not_prefix():
-    assert resolver.is_prefix("JAN 2019") is False
     assert resolver.is_prefix("JAN JAN JAN") is False
+    assert resolver.is_prefix("00 4") is False
 
 
 def test_parse_m_d_y():
@@ -54,6 +61,7 @@ def test_parse_m_d_y():
     assert parse_date("SEPTEMBER 15 2019") == date(2019, 9, 15)
     assert parse_date("09/15/2019") == date(2019, 9, 15)
     assert parse_date("09/15/19") == date(2019, 9, 15)
+    assert parse_date("2019-JAN-01") == date(2019, 1, 1)
 
     # MDY > DMY
     assert parse_date("12/11/2019") == date(2019, 12, 11)
@@ -77,6 +85,7 @@ def test_parse_d_m_y():
     # DMY wins when D > 12
     assert parse_date("15/09/2019") == date(2019, 9, 15)
     assert parse_date("15/09/19") == date(2019, 9, 15)
+    assert parse_date("15\\09\\19") == date(2019, 9, 15)
 
 
 def test_parse_y_m_d():
@@ -89,8 +98,14 @@ def test_parse_incomplete():
     assert parse_date("2019 01") is None
     assert parse_date("2019 01") is None
     assert parse_date("2019-01-") is None
-    assert parse_date("2019-01-0") is None
+    assert parse_date("2019-01-0") == date(2019, 1, 1)
 
 
 def test_failure_cases():
     assert parse_date("2019-13-13") is None
+    assert parse_date("00 4-5") is None
+
+
+def test_no_day_of_month():
+    assert parse_ent("September 2011").name == "2011-09"
+    assert parse_ent("JAN 2020").name == "2020-01"
