@@ -4,7 +4,7 @@ from entitykb import (
     F,
     SearchRequest,
     T,
-    EdgeRequest,
+    NeighborRequest,
     Node,
 )
 
@@ -37,6 +37,7 @@ def test_roundtrip():
                     }
                 ],
                 "exclude": False,
+                "skip_limit": 1000,
             },
         ],
     }
@@ -47,5 +48,5 @@ def test_roundtrip():
 def test_edge_request():
     node = Node()
     # noinspection PyTypeChecker
-    request = EdgeRequest(node_key=node)
+    request = NeighborRequest(node_key=node)
     assert request.node_key == node.key
